@@ -158,7 +158,7 @@ def _assert_same_type(variable, type_from_variable):
             raise TypeError(f"Variable {variable=} different type than expected {type_from_variable=}")
 
 
-def assert_same_type(variable, type_from_variable, alternative=None):
+def assert_same_type_as(variable, type_from_variable, alternative=None):
     """Check if `variable` is same type as `type_from_variable` unless `variable` is `alternative`"""
     if variable is alternative:
         return
@@ -168,6 +168,12 @@ def assert_same_type(variable, type_from_variable, alternative=None):
         raise TypeError(f"Variable {variable} not of expected type {type_from_variable}")
 
 
+def all_same_type(variable_list, type_):
+    for var in variable_list:
+        if not isinstance(var, type_):
+            raise ValueError(f"{var} not of type {type_.__name__}!")
+
+
 def assert_shape(variable, shape: t.Tuple, name: str = None, ignore_none: bool = True):
     if ignore_none:
         if variable is None:
